import { select, 
        csv, 
        scaleLinear, 
        extent, 
        scaleBand,
        scaleTime,
        axisLeft,
        axisBottom,
        line,
       	curveBasis } from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'A Week of Temperature in San Francisco'
  const xValue = d => d.timestamp;
  const xAxisLabel = 'Time';
  const yValue = d => d.temperature;
  const yAxisLabel = 'Temperature';
  const circleRadius = 6;
  const margin = { top: 50, left: 70, right: 50, bottom: 55};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  // console.log(xScale.domain());
    
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  // const yAxis = axisLeft(yScale);

  // The whole thing is contained in group g, as we need to have identical margins. 
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  // yAxis(g.append('g'));
  
  // A shortened version of appending a new group element that corresponds to the yAxis. Method "call" takes in the yAxis that we have just created.
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(10);
    
  // Here is the yAxis. 
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(5);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.attr('transform', `rotate(-90)`)
  	.attr('class', 'axis-label')
  	.attr('x', -innerHeight/2)
  	.attr('y', -33)
  	.attr('fill', 'black')
  	.style('text-anchor', 'middle')
  	.text(yAxisLabel);
  
  // Here is the xAxis. 
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('x', innerWidth/2)
  	.attr('y', 35)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', lineGenerator(data));
  
	// g.selectAll('circle').data(data)
	// .enter().append('circle')
	// .attr('cy', d => yScale(yValue(d)))
	// .attr('cx', d => xScale(xValue(d)))
	// .attr('r', circleRadius);
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('x', 235)
  	.attr('y', -15)
  	.text(title)
}

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv').then(data => {
  data.forEach(d => {
  	d.temperature = +d.temperature;
    d.timestamp = new Date(d.timestamp);
  });
	render(data);
});